import sys
import logging
from sylo.definitions import ROOT_DIR
logger = logging.getLogger(__name__)


LOG_FILE_NAME = f'{ROOT_DIR}/../sylo.log'
LOG_FILE_FORMAT = '%(asctime)s %(module)s %(levelname)s: %(message)s'
DEFAULT_LOG_LEVEL = logging.WARN


def logging_config(log_arg: str = None):
    if log_arg:
        log_level = log_arg
        handler = logging.StreamHandler(sys.stdout)
        logging.basicConfig(
            level=log_level,
            filename=LOG_FILE_NAME,
            filemode='w'
        )

    else:
        log_level = DEFAULT_LOG_LEVEL
        handler = None
        logging.basicConfig(
            level=log_level,
        )

    if handler:
        logging.getLogger().addHandler(handler)



import logging
from sylo.timer import run
from sylo.args import get_arguments
from sylo.logging import logging_config
from sylo.messages import set_theme
logger = logging.getLogger(__name__)


def main():
    args = get_arguments()
    logging_config(args.log)
    set_theme(args.theme)
    run(args)
    logger.info('Started from cli')



import argparse


def get_arguments():
    parser = argparse.ArgumentParser(
        description="Sort Your Life Out! Python Pomodoro Timer"
    )
    parser.add_argument(
        "-w",
        "--work_time",
        help="Set the work time length",
        type=int)
    parser.add_argument(
        "-r",
        "--rest_time",
        help="Set the rest time length",
        type=int
    )
    parser.add_argument(
        "-a",
        "--audio_file",
        help="""Set the full path to an audio \
        file you want to be played on completion of a timer""",
        type=str
    )
    parser.add_argument(
        "-l",
        "--log",
        help="Set the log level",
        type=str,
        choices=[
            'DEBUG',
            'INFO',
        ]
    )
    parser.add_argument(
        "-s",
        '--speed_mode',
        dest='speed_mode',
        action='store_true'
    )
    parser.add_argument(
        "-t",
        "--theme",
        help="Set the color scheme",
        type=str,
        choices=[
            'blue',
            'red',
            'green',
            'lblue',
            'lred',
            'lgreen',
            'magenta',
            'yellow',
            'white',
            'black',
        ]
    )
    parser.set_defaults(
        speed_mode=False,
        theme='blue'
    )
    return parser.parse_args()
